︠91a256e3-9df1-4663-bd64-466b197f6f88︠
#Exploring second degree Bezier curves with weigths
︡6ccba18f-e30e-4862-b49b-1e32772b0964︡︡
︠ed8365f8-eb72-4b7c-ac5c-7a3eb6881592︠
#The control points defining the curve
b0=vector([1,0])
b1=vector([1,1])
b2=vector([0,1])
︡98d17a6f-bede-4520-9f4b-c99434b668e9︡︡
︠63e6456e-bb51-45cf-bbaa-eb61642ddbce︠
#The Bernstein polynomial
def Bpoly(t,n,i):
    return binomial(n,i)*t^i*(1-t)^(n-i)
︡81820ef9-e5aa-49ba-8870-3d3910a2c277︡︡
︠ed158d2f-176a-4aa1-ab69-58f52cfeb518︠
#The Bezier curve of degree 2 defined by the control points
var('t')
bez=Bpoly(t,2,0)*b0+Bpoly(t,2,1)*b1+Bpoly(t,2,2)*b2
print bez
︡0076972e-5aa9-4c1b-8d46-c1228ff11795︡{"stdout": "((t - 1)^2 - 2*(t - 1)*t, -2*(t - 1)*t + t^2)"}︡
︠42881df9-c256-448c-8cce-c06786446ecc︠
#Plotting the Bezier curve, t in [0,1]
parametric_plot(bez,(0,1),aspect_ratio=1)
︡9f31b6cf-72d4-4bc4-9ac7-5f1b5fb80588︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠dfdfcd5c-d5e4-49e6-a099-4c950b0f79a6︠
#We now want to explore how the curve changes when we introduce weights
︡3acee525-0baa-48b3-b099-73ce10681308︡︡
︠87ab639b-43f6-4e07-854a-e16cd414f234︠
#Defining the weights as variables, and using them to define the new control points. Note that the points are now in projective 3-space.
var('w0 w1 w2')
b0_=w0*vector([1,b0[0],b0[1]])
b1_=w1*vector([1,b1[0],b1[1]])
b2_=w2*vector([1,b2[0],b2[1]])
print b0_, b1_, b2_
︡49d55b62-defe-44b9-bac8-e21b617651bc︡{"stdout": "(w0, w0, 0) (w1, w1, w1) (w2, 0, w2)"}︡
︠9d7c3290-04f7-441b-84a8-2fae5b9e0d5b︠
#The Bezier curve defined by the points:
var('t')
bez_=Bpoly(t,2,0)*b0_+Bpoly(t,2,1)*b1_+Bpoly(t,2,2)*b2_
print bez_
︡918774ed-84c1-44b3-b4bc-c249632ac1d4︡{"stdout": "((t - 1)^2*w0 - 2*(t - 1)*t*w1 + t^2*w2, (t - 1)^2*w0 - 2*(t - 1)*t*w1, -2*(t - 1)*t*w1 + t^2*w2)"}︡
︠27ad1774-9368-42af-b26b-aaed256e3686︠
#In order to plot the curve, we project the affine plane (using the first coordinate)
def projection(p_):
    return vector([p_[1]/p_[0],p_[2]/p_[0]])
︡fca2f70e-4f5c-4a62-89a7-0ec22b9c1bcc︡︡
︠a17108cc-1c60-4d33-98f3-bea504cc183c︠
#Projecting the Bezier curve
bez1=projection(bez_)
print bez1
︡a72eaac9-382a-4b2e-a63c-e634f6d96f23︡{"stdout": "(((t - 1)^2*w0 - 2*(t - 1)*t*w1)/((t - 1)^2*w0 - 2*(t - 1)*t*w1 + t^2*w2), -(2*(t - 1)*t*w1 - t^2*w2)/((t - 1)^2*w0 - 2*(t - 1)*t*w1 + t^2*w2))"}︡
︠e459e818-9cc7-4047-aa83-45c762761e48︠
#We also need to assign a value to the "wi"s before we can plot
bez2=bez1(w0=1,w1=1,w2=1)
︡f781183d-15ff-446d-be82-c36581113d78︡︡
︠0f5f6fc6-74ed-43d2-a069-7864d8f1aa18︠
#Finally we can plot the curve:
parametric_plot(bez2,(0,1),aspect_ratio=1)
︡246a0f34-1ff6-4159-9226-881886b7360b︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠0e9bf56d-eec5-405e-a0c2-f1bd2ec65b2f︠
#We now want to be able to manipulate the weights and see the effect on the curve.
︡149df98d-34a6-4fbf-862f-c744b4d09901︡︡
︠35663d09-8d26-4124-8dfa-ecd93c15d4e0︠
@interact
def weighted_bezier_curve(
    W0=(0.001,5),
    W1=(0,5),
    W2=(0,5)
    ):    

    graph=parametric_plot(bez1(w0=W0,w1=W1,w2=W2),(0,1),aspect_ratio=1)
    graph.show(figsize=3)
#The minimum for W0 is >0 to avoid error message on first display.
︡4b4ec6c5-f1a0-4a13-80de-5c0f419597c1︡{"html": "<!--notruncate--><div padding=6 id='div-interact-26'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">W0&nbsp;</font></td><td><table><tr><td>\n        <div id='slider-W0-26' style='margin:0px; margin-left: 1.0em; margin-right: 1.0em; width: 15.0em;'></div>\n        </td><td><font color='black' id='slider-W0-26-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.00100000000000000\",\"0.0110180360721443\",\"0.0210360721442886\",\"0.0310541082164329\",\"0.0410721442885772\",\"0.0510901803607214\",\"0.0611082164328657\",\"0.0711262525050100\",\"0.0811442885771543\",\"0.0911623246492986\",\"0.101180360721443\",\"0.111198396793587\",\"0.121216432865731\",\"0.131234468937876\",\"0.141252505010020\",\"0.151270541082164\",\"0.161288577154309\",\"0.171306613226453\",\"0.181324649298597\",\"0.191342685370742\",\"0.201360721442886\",\"0.211378757515030\",\"0.221396793587174\",\"0.231414829659319\",\"0.241432865731463\",\"0.251450901803607\",\"0.261468937875752\",\"0.271486973947896\",\"0.281505010020040\",\"0.291523046092184\",\"0.301541082164329\",\"0.311559118236473\",\"0.321577154308617\",\"0.331595190380762\",\"0.341613226452906\",\"0.351631262525050\",\"0.361649298597195\",\"0.371667334669339\",\"0.381685370741483\",\"0.391703406813627\",\"0.401721442885772\",\"0.411739478957916\",\"0.421757515030060\",\"0.431775551102205\",\"0.441793587174349\",\"0.451811623246493\",\"0.461829659318638\",\"0.471847695390782\",\"0.481865731462926\",\"0.491883767535070\",\"0.501901803607215\",\"0.511919839679359\",\"0.521937875751503\",\"0.531955911823647\",\"0.541973947895792\",\"0.551991983967936\",\"0.562010020040080\",\"0.572028056112224\",\"0.582046092184369\",\"0.592064128256513\",\"0.602082164328657\",\"0.612100200400801\",\"0.622118236472946\",\"0.632136272545090\",\"0.642154308617234\",\"0.652172344689378\",\"0.662190380761523\",\"0.672208416833667\",\"0.682226452905811\",\"0.692244488977955\",\"0.702262525050100\",\"0.712280561122244\",\"0.722298597194388\",\"0.732316633266532\",\"0.742334669338677\",\"0.752352705410821\",\"0.762370741482965\",\"0.772388777555109\",\"0.782406813627254\",\"0.792424849699398\",\"0.802442885771542\",\"0.812460921843686\",\"0.822478957915830\",\"0.832496993987975\",\"0.842515030060119\",\"0.852533066132263\",\"0.862551102204407\",\"0.872569138276552\",\"0.882587174348696\",\"0.892605210420840\",\"0.902623246492984\",\"0.912641282565129\",\"0.922659318637273\",\"0.932677354709417\",\"0.942695390781561\",\"0.952713426853706\",\"0.962731462925850\",\"0.972749498997994\",\"0.982767535070138\",\"0.992785571142283\",\"1.00280360721443\",\"1.01282164328657\",\"1.02283967935872\",\"1.03285771543086\",\"1.04287575150300\",\"1.05289378757515\",\"1.06291182364729\",\"1.07292985971944\",\"1.08294789579158\",\"1.09296593186373\",\"1.10298396793587\",\"1.11300200400801\",\"1.12302004008016\",\"1.13303807615230\",\"1.14305611222445\",\"1.15307414829659\",\"1.16309218436873\",\"1.17311022044088\",\"1.18312825651302\",\"1.19314629258517\",\"1.20316432865731\",\"1.21318236472946\",\"1.22320040080160\",\"1.23321843687374\",\"1.24323647294589\",\"1.25325450901803\",\"1.26327254509018\",\"1.27329058116232\",\"1.28330861723447\",\"1.29332665330661\",\"1.30334468937875\",\"1.31336272545090\",\"1.32338076152304\",\"1.33339879759519\",\"1.34341683366733\",\"1.35343486973948\",\"1.36345290581162\",\"1.37347094188376\",\"1.38348897795591\",\"1.39350701402805\",\"1.40352505010020\",\"1.41354308617234\",\"1.42356112224449\",\"1.43357915831663\",\"1.44359719438877\",\"1.45361523046092\",\"1.46363326653306\",\"1.47365130260521\",\"1.48366933867735\",\"1.49368737474949\",\"1.50370541082164\",\"1.51372344689378\",\"1.52374148296593\",\"1.53375951903807\",\"1.54377755511022\",\"1.55379559118236\",\"1.56381362725450\",\"1.57383166332665\",\"1.58384969939879\",\"1.59386773547094\",\"1.60388577154308\",\"1.61390380761523\",\"1.62392184368737\",\"1.63393987975951\",\"1.64395791583166\",\"1.65397595190380\",\"1.66399398797595\",\"1.67401202404809\",\"1.68403006012024\",\"1.69404809619238\",\"1.70406613226452\",\"1.71408416833667\",\"1.72410220440881\",\"1.73412024048096\",\"1.74413827655310\",\"1.75415631262525\",\"1.76417434869739\",\"1.77419238476953\",\"1.78421042084168\",\"1.79422845691382\",\"1.80424649298597\",\"1.81426452905811\",\"1.82428256513025\",\"1.83430060120240\",\"1.84431863727454\",\"1.85433667334669\",\"1.86435470941883\",\"1.87437274549098\",\"1.88439078156312\",\"1.89440881763526\",\"1.90442685370741\",\"1.91444488977955\",\"1.92446292585170\",\"1.93448096192384\",\"1.94449899799599\",\"1.95451703406813\",\"1.96453507014027\",\"1.97455310621242\",\"1.98457114228456\",\"1.99458917835671\",\"2.00460721442885\",\"2.01462525050100\",\"2.02464328657314\",\"2.03466132264528\",\"2.04467935871743\",\"2.05469739478957\",\"2.06471543086172\",\"2.07473346693386\",\"2.08475150300601\",\"2.09476953907815\",\"2.10478757515030\",\"2.11480561122244\",\"2.12482364729458\",\"2.13484168336673\",\"2.14485971943887\",\"2.15487775551102\",\"2.16489579158316\",\"2.17491382765531\",\"2.18493186372745\",\"2.19494989979960\",\"2.20496793587174\",\"2.21498597194388\",\"2.22500400801603\",\"2.23502204408817\",\"2.24504008016032\",\"2.25505811623246\",\"2.26507615230461\",\"2.27509418837675\",\"2.28511222444890\",\"2.29513026052104\",\"2.30514829659319\",\"2.31516633266533\",\"2.32518436873747\",\"2.33520240480962\",\"2.34522044088176\",\"2.35523847695391\",\"2.36525651302605\",\"2.37527454909820\",\"2.38529258517034\",\"2.39531062124249\",\"2.40532865731463\",\"2.41534669338677\",\"2.42536472945892\",\"2.43538276553106\",\"2.44540080160321\",\"2.45541883767535\",\"2.46543687374750\",\"2.47545490981964\",\"2.48547294589179\",\"2.49549098196393\",\"2.50550901803607\",\"2.51552705410822\",\"2.52554509018036\",\"2.53556312625251\",\"2.54558116232465\",\"2.55559919839680\",\"2.56561723446894\",\"2.57563527054109\",\"2.58565330661323\",\"2.59567134268537\",\"2.60568937875752\",\"2.61570741482966\",\"2.62572545090181\",\"2.63574348697395\",\"2.64576152304610\",\"2.65577955911824\",\"2.66579759519039\",\"2.67581563126253\",\"2.68583366733467\",\"2.69585170340682\",\"2.70586973947896\",\"2.71588777555111\",\"2.72590581162325\",\"2.73592384769540\",\"2.74594188376754\",\"2.75595991983969\",\"2.76597795591183\",\"2.77599599198397\",\"2.78601402805612\",\"2.79603206412826\",\"2.80605010020041\",\"2.81606813627255\",\"2.82608617234470\",\"2.83610420841684\",\"2.84612224448899\",\"2.85614028056113\",\"2.86615831663328\",\"2.87617635270542\",\"2.88619438877756\",\"2.89621242484971\",\"2.90623046092185\",\"2.91624849699400\",\"2.92626653306614\",\"2.93628456913829\",\"2.94630260521043\",\"2.95632064128258\",\"2.96633867735472\",\"2.97635671342686\",\"2.98637474949901\",\"2.99639278557115\",\"3.00641082164330\",\"3.01642885771544\",\"3.02644689378759\",\"3.03646492985973\",\"3.04648296593188\",\"3.05650100200402\",\"3.06651903807616\",\"3.07653707414831\",\"3.08655511022045\",\"3.09657314629260\",\"3.10659118236474\",\"3.11660921843689\",\"3.12662725450903\",\"3.13664529058118\",\"3.14666332665332\",\"3.15668136272546\",\"3.16669939879761\",\"3.17671743486975\",\"3.18673547094190\",\"3.19675350701404\",\"3.20677154308619\",\"3.21678957915833\",\"3.22680761523048\",\"3.23682565130262\",\"3.24684368737476\",\"3.25686172344691\",\"3.26687975951905\",\"3.27689779559120\",\"3.28691583166334\",\"3.29693386773549\",\"3.30695190380763\",\"3.31696993987978\",\"3.32698797595192\",\"3.33700601202406\",\"3.34702404809621\",\"3.35704208416835\",\"3.36706012024050\",\"3.37707815631264\",\"3.38709619238479\",\"3.39711422845693\",\"3.40713226452908\",\"3.41715030060122\",\"3.42716833667337\",\"3.43718637274551\",\"3.44720440881765\",\"3.45722244488980\",\"3.46724048096194\",\"3.47725851703409\",\"3.48727655310623\",\"3.49729458917838\",\"3.50731262525052\",\"3.51733066132267\",\"3.52734869739481\",\"3.53736673346695\",\"3.54738476953910\",\"3.55740280561124\",\"3.56742084168339\",\"3.57743887775553\",\"3.58745691382768\",\"3.59747494989982\",\"3.60749298597197\",\"3.61751102204411\",\"3.62752905811625\",\"3.63754709418840\",\"3.64756513026054\",\"3.65758316633269\",\"3.66760120240483\",\"3.67761923847698\",\"3.68763727454912\",\"3.69765531062127\",\"3.70767334669341\",\"3.71769138276555\",\"3.72770941883770\",\"3.73772745490984\",\"3.74774549098199\",\"3.75776352705413\",\"3.76778156312628\",\"3.77779959919842\",\"3.78781763527057\",\"3.79783567134271\",\"3.80785370741485\",\"3.81787174348700\",\"3.82788977955914\",\"3.83790781563129\",\"3.84792585170343\",\"3.85794388777558\",\"3.86796192384772\",\"3.87797995991987\",\"3.88799799599201\",\"3.89801603206416\",\"3.90803406813630\",\"3.91805210420844\",\"3.92807014028059\",\"3.93808817635273\",\"3.94810621242488\",\"3.95812424849702\",\"3.96814228456917\",\"3.97816032064131\",\"3.98817835671346\",\"3.99819639278560\",\"4.00821442885774\",\"4.01823246492989\",\"4.02825050100203\",\"4.03826853707418\",\"4.04828657314632\",\"4.05830460921846\",\"4.06832264529061\",\"4.07834068136275\",\"4.08835871743490\",\"4.09837675350704\",\"4.10839478957918\",\"4.11841282565133\",\"4.12843086172347\",\"4.13844889779562\",\"4.14846693386776\",\"4.15848496993990\",\"4.16850300601205\",\"4.17852104208419\",\"4.18853907815634\",\"4.19855711422848\",\"4.20857515030062\",\"4.21859318637277\",\"4.22861122244491\",\"4.23862925851706\",\"4.24864729458920\",\"4.25866533066134\",\"4.26868336673349\",\"4.27870140280563\",\"4.28871943887778\",\"4.29873747494992\",\"4.30875551102206\",\"4.31877354709421\",\"4.32879158316635\",\"4.33880961923850\",\"4.34882765531064\",\"4.35884569138278\",\"4.36886372745493\",\"4.37888176352707\",\"4.38889979959922\",\"4.39891783567136\",\"4.40893587174350\",\"4.41895390781565\",\"4.42897194388779\",\"4.43898997995994\",\"4.44900801603208\",\"4.45902605210422\",\"4.46904408817637\",\"4.47906212424851\",\"4.48908016032066\",\"4.49909819639280\",\"4.50911623246494\",\"4.51913426853709\",\"4.52915230460923\",\"4.53917034068138\",\"4.54918837675352\",\"4.55920641282566\",\"4.56922444889781\",\"4.57924248496995\",\"4.58926052104210\",\"4.59927855711424\",\"4.60929659318638\",\"4.61931462925853\",\"4.62933266533067\",\"4.63935070140282\",\"4.64936873747496\",\"4.65938677354711\",\"4.66940480961925\",\"4.67942284569139\",\"4.68944088176354\",\"4.69945891783568\",\"4.70947695390783\",\"4.71949498997997\",\"4.72951302605211\",\"4.73953106212426\",\"4.74954909819640\",\"4.75956713426855\",\"4.76958517034069\",\"4.77960320641283\",\"4.78962124248498\",\"4.79963927855712\",\"4.80965731462927\",\"4.81967535070141\",\"4.82969338677355\",\"4.83971142284570\",\"4.84972945891784\",\"4.85974749498999\",\"4.86976553106213\",\"4.87978356713427\",\"4.88980160320642\",\"4.89981963927856\",\"4.90983767535071\",\"4.91985571142285\",\"4.92987374749499\",\"4.93989178356714\",\"4.94990981963928\",\"4.95992785571143\",\"4.96994589178357\",\"4.97996392785571\",\"4.98998196392786\",\"5.00000000000000\"]; setTimeout(function() {\n    $('#slider-W0-26').slider({\n        step: 1, min: 0, max: 499, value: 0,\n        change: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-W0-26-lbl').text(values[position]); interact(26, \"_interact_.update(26, \\\"W0\\\", 1, _interact_.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());_interact_.recompute(26)\"); },\n        slide: function(e,ui) { if(values!=null) $('#slider-W0-26-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-W0-26-lbl').text(values[$('#slider-W0-26').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">W1&nbsp;</font></td><td><table><tr><td>\n        <div id='slider-W1-26' style='margin:0px; margin-left: 1.0em; margin-right: 1.0em; width: 15.0em;'></div>\n        </td><td><font color='black' id='slider-W1-26-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.0\",\"0.01002004008016032\",\"0.02004008016032064\",\"0.030060120240480961\",\"0.040080160320641281\",\"0.050100200400801598\",\"0.060120240480961915\",\"0.070140280561122231\",\"0.080160320641282548\",\"0.090180360721442865\",\"0.10020040080160318\",\"0.1102204408817635\",\"0.12024048096192382\",\"0.13026052104208413\",\"0.14028056112224446\",\"0.15030060120240479\",\"0.16032064128256512\",\"0.17034068136272545\",\"0.18036072144288579\",\"0.19038076152304612\",\"0.20040080160320645\",\"0.21042084168336678\",\"0.22044088176352711\",\"0.23046092184368744\",\"0.24048096192384777\",\"0.2505010020040081\",\"0.26052104208416843\",\"0.27054108216432876\",\"0.28056112224448909\",\"0.29058116232464942\",\"0.30060120240480975\",\"0.31062124248497008\",\"0.32064128256513041\",\"0.33066132264529075\",\"0.34068136272545108\",\"0.35070140280561141\",\"0.36072144288577174\",\"0.37074148296593207\",\"0.3807615230460924\",\"0.39078156312625273\",\"0.40080160320641306\",\"0.41082164328657339\",\"0.42084168336673372\",\"0.43086172344689405\",\"0.44088176352705438\",\"0.45090180360721471\",\"0.46092184368737504\",\"0.47094188376753537\",\"0.4809619238476957\",\"0.49098196392785604\",\"0.50100200400801631\",\"0.51102204408817664\",\"0.52104208416833697\",\"0.5310621242484973\",\"0.54108216432865763\",\"0.55110220440881796\",\"0.56112224448897829\",\"0.57114228456913863\",\"0.58116232464929896\",\"0.59118236472945929\",\"0.60120240480961962\",\"0.61122244488977995\",\"0.62124248496994028\",\"0.63126252505010061\",\"0.64128256513026094\",\"0.65130260521042127\",\"0.6613226452905816\",\"0.67134268537074193\",\"0.68136272545090226\",\"0.69138276553106259\",\"0.70140280561122292\",\"0.71142284569138325\",\"0.72144288577154358\",\"0.73146292585170392\",\"0.74148296593186425\",\"0.75150300601202458\",\"0.76152304609218491\",\"0.77154308617234524\",\"0.78156312625250557\",\"0.7915831663326659\",\"0.80160320641282623\",\"0.81162324649298656\",\"0.82164328657314689\",\"0.83166332665330722\",\"0.84168336673346755\",\"0.85170340681362788\",\"0.86172344689378821\",\"0.87174348697394854\",\"0.88176352705410888\",\"0.89178356713426921\",\"0.90180360721442954\",\"0.91182364729458987\",\"0.9218436873747502\",\"0.93186372745491053\",\"0.94188376753507086\",\"0.95190380761523119\",\"0.96192384769539152\",\"0.97194388777555185\",\"0.98196392785571218\",\"0.99198396793587251\",\"1.0020040080160328\",\"1.0120240480961931\",\"1.0220440881763533\",\"1.0320641282565135\",\"1.0420841683366737\",\"1.0521042084168339\",\"1.0621242484969942\",\"1.0721442885771544\",\"1.0821643286573146\",\"1.0921843687374748\",\"1.102204408817635\",\"1.1122244488977953\",\"1.1222444889779555\",\"1.1322645290581157\",\"1.1422845691382759\",\"1.1523046092184361\",\"1.1623246492985964\",\"1.1723446893787566\",\"1.1823647294589168\",\"1.192384769539077\",\"1.2024048096192372\",\"1.2124248496993975\",\"1.2224448897795577\",\"1.2324649298597179\",\"1.2424849699398781\",\"1.2525050100200383\",\"1.2625250501001986\",\"1.2725450901803588\",\"1.282565130260519\",\"1.2925851703406792\",\"1.3026052104208394\",\"1.3126252505009997\",\"1.3226452905811599\",\"1.3326653306613201\",\"1.3426853707414803\",\"1.3527054108216405\",\"1.3627254509018008\",\"1.372745490981961\",\"1.3827655310621212\",\"1.3927855711422814\",\"1.4028056112224416\",\"1.4128256513026018\",\"1.4228456913827621\",\"1.4328657314629223\",\"1.4428857715430825\",\"1.4529058116232427\",\"1.4629258517034029\",\"1.4729458917835632\",\"1.4829659318637234\",\"1.4929859719438836\",\"1.5030060120240438\",\"1.513026052104204\",\"1.5230460921843643\",\"1.5330661322645245\",\"1.5430861723446847\",\"1.5531062124248449\",\"1.5631262525050051\",\"1.5731462925851654\",\"1.5831663326653256\",\"1.5931863727454858\",\"1.603206412825646\",\"1.6132264529058062\",\"1.6232464929859665\",\"1.6332665330661267\",\"1.6432865731462869\",\"1.6533066132264471\",\"1.6633266533066073\",\"1.6733466933867676\",\"1.6833667334669278\",\"1.693386773547088\",\"1.7034068136272482\",\"1.7134268537074084\",\"1.7234468937875687\",\"1.7334669338677289\",\"1.7434869739478891\",\"1.7535070140280493\",\"1.7635270541082095\",\"1.7735470941883698\",\"1.78356713426853\",\"1.7935871743486902\",\"1.8036072144288504\",\"1.8136272545090106\",\"1.8236472945891709\",\"1.8336673346693311\",\"1.8436873747494913\",\"1.8537074148296515\",\"1.8637274549098117\",\"1.873747494989972\",\"1.8837675350701322\",\"1.8937875751502924\",\"1.9038076152304526\",\"1.9138276553106128\",\"1.923847695390773\",\"1.9338677354709333\",\"1.9438877755510935\",\"1.9539078156312537\",\"1.9639278557114139\",\"1.9739478957915741\",\"1.9839679358717344\",\"1.9939879759518946\",\"2.004008016032055\",\"2.0140280561122155\",\"2.0240480961923759\",\"2.0340681362725364\",\"2.0440881763526968\",\"2.0541082164328572\",\"2.0641282565130177\",\"2.0741482965931781\",\"2.0841683366733386\",\"2.094188376753499\",\"2.1042084168336594\",\"2.1142284569138199\",\"2.1242484969939803\",\"2.1342685370741408\",\"2.1442885771543012\",\"2.1543086172344617\",\"2.1643286573146221\",\"2.1743486973947825\",\"2.184368737474943\",\"2.1943887775551034\",\"2.2044088176352639\",\"2.2144288577154243\",\"2.2244488977955847\",\"2.2344689378757452\",\"2.2444889779559056\",\"2.2545090180360661\",\"2.2645290581162265\",\"2.274549098196387\",\"2.2845691382765474\",\"2.2945891783567078\",\"2.3046092184368683\",\"2.3146292585170287\",\"2.3246492985971892\",\"2.3346693386773496\",\"2.34468937875751\",\"2.3547094188376705\",\"2.3647294589178309\",\"2.3747494989979914\",\"2.3847695390781518\",\"2.3947895791583123\",\"2.4048096192384727\",\"2.4148296593186331\",\"2.4248496993987936\",\"2.434869739478954\",\"2.4448897795591145\",\"2.4549098196392749\",\"2.4649298597194353\",\"2.4749498997995958\",\"2.4849699398797562\",\"2.4949899799599167\",\"2.5050100200400771\",\"2.5150300601202376\",\"2.525050100200398\",\"2.5350701402805584\",\"2.5450901803607189\",\"2.5551102204408793\",\"2.5651302605210398\",\"2.5751503006012002\",\"2.5851703406813606\",\"2.5951903807615211\",\"2.6052104208416815\",\"2.615230460921842\",\"2.6252505010020024\",\"2.6352705410821629\",\"2.6452905811623233\",\"2.6553106212424837\",\"2.6653306613226442\",\"2.6753507014028046\",\"2.6853707414829651\",\"2.6953907815631255\",\"2.7054108216432859\",\"2.7154308617234464\",\"2.7254509018036068\",\"2.7354709418837673\",\"2.7454909819639277\",\"2.7555110220440882\",\"2.7655310621242486\",\"2.775551102204409\",\"2.7855711422845695\",\"2.7955911823647299\",\"2.8056112224448904\",\"2.8156312625250508\",\"2.8256513026052112\",\"2.8356713426853717\",\"2.8456913827655321\",\"2.8557114228456926\",\"2.865731462925853\",\"2.8757515030060135\",\"2.8857715430861739\",\"2.8957915831663343\",\"2.9058116232464948\",\"2.9158316633266552\",\"2.9258517034068157\",\"2.9358717434869761\",\"2.9458917835671365\",\"2.955911823647297\",\"2.9659318637274574\",\"2.9759519038076179\",\"2.9859719438877783\",\"2.9959919839679388\",\"3.0060120240480992\",\"3.0160320641282596\",\"3.0260521042084201\",\"3.0360721442885805\",\"3.046092184368741\",\"3.0561122244489014\",\"3.0661322645290618\",\"3.0761523046092223\",\"3.0861723446893827\",\"3.0961923847695432\",\"3.1062124248497036\",\"3.1162324649298641\",\"3.1262525050100245\",\"3.1362725450901849\",\"3.1462925851703454\",\"3.1563126252505058\",\"3.1663326653306663\",\"3.1763527054108267\",\"3.1863727454909871\",\"3.1963927855711476\",\"3.206412825651308\",\"3.2164328657314685\",\"3.2264529058116289\",\"3.2364729458917894\",\"3.2464929859719498\",\"3.2565130260521102\",\"3.2665330661322707\",\"3.2765531062124311\",\"3.2865731462925916\",\"3.296593186372752\",\"3.3066132264529124\",\"3.3166332665330729\",\"3.3266533066132333\",\"3.3366733466933938\",\"3.3466933867735542\",\"3.3567134268537147\",\"3.3667334669338751\",\"3.3767535070140355\",\"3.386773547094196\",\"3.3967935871743564\",\"3.4068136272545169\",\"3.4168336673346773\",\"3.4268537074148377\",\"3.4368737474949982\",\"3.4468937875751586\",\"3.4569138276553191\",\"3.4669338677354795\",\"3.47695390781564\",\"3.4869739478958004\",\"3.4969939879759608\",\"3.5070140280561213\",\"3.5170340681362817\",\"3.5270541082164422\",\"3.5370741482966026\",\"3.547094188376763\",\"3.5571142284569235\",\"3.5671342685370839\",\"3.5771543086172444\",\"3.5871743486974048\",\"3.5971943887775653\",\"3.6072144288577257\",\"3.6172344689378861\",\"3.6272545090180466\",\"3.637274549098207\",\"3.6472945891783675\",\"3.6573146292585279\",\"3.6673346693386883\",\"3.6773547094188488\",\"3.6873747494990092\",\"3.6973947895791697\",\"3.7074148296593301\",\"3.7174348697394906\",\"3.727454909819651\",\"3.7374749498998114\",\"3.7474949899799719\",\"3.7575150300601323\",\"3.7675350701402928\",\"3.7775551102204532\",\"3.7875751503006136\",\"3.7975951903807741\",\"3.8076152304609345\",\"3.817635270541095\",\"3.8276553106212554\",\"3.8376753507014159\",\"3.8476953907815763\",\"3.8577154308617367\",\"3.8677354709418972\",\"3.8777555110220576\",\"3.8877755511022181\",\"3.8977955911823785\",\"3.9078156312625389\",\"3.9178356713426994\",\"3.9278557114228598\",\"3.9378757515030203\",\"3.9478957915831807\",\"3.9579158316633412\",\"3.9679358717435016\",\"3.977955911823662\",\"3.9879759519038225\",\"3.9979959919839829\",\"4.0080160320641429\",\"4.0180360721443034\",\"4.0280561122244638\",\"4.0380761523046242\",\"4.0480961923847847\",\"4.0581162324649451\",\"4.0681362725451056\",\"4.078156312625266\",\"4.0881763527054265\",\"4.0981963927855869\",\"4.1082164328657473\",\"4.1182364729459078\",\"4.1282565130260682\",\"4.1382765531062287\",\"4.1482965931863891\",\"4.1583166332665495\",\"4.16833667334671\",\"4.1783567134268704\",\"4.1883767535070309\",\"4.1983967935871913\",\"4.2084168336673518\",\"4.2184368737475122\",\"4.2284569138276726\",\"4.2384769539078331\",\"4.2484969939879935\",\"4.258517034068154\",\"4.2685370741483144\",\"4.2785571142284748\",\"4.2885771543086353\",\"4.2985971943887957\",\"4.3086172344689562\",\"4.3186372745491166\",\"4.3286573146292771\",\"4.3386773547094375\",\"4.3486973947895979\",\"4.3587174348697584\",\"4.3687374749499188\",\"4.3787575150300793\",\"4.3887775551102397\",\"4.3987975951904001\",\"4.4088176352705606\",\"4.418837675350721\",\"4.4288577154308815\",\"4.4388777555110419\",\"4.4488977955912024\",\"4.4589178356713628\",\"4.4689378757515232\",\"4.4789579158316837\",\"4.4889779559118441\",\"4.4989979959920046\",\"4.509018036072165\",\"4.5190380761523254\",\"4.5290581162324859\",\"4.5390781563126463\",\"4.5490981963928068\",\"4.5591182364729672\",\"4.5691382765531277\",\"4.5791583166332881\",\"4.5891783567134485\",\"4.599198396793609\",\"4.6092184368737694\",\"4.6192384769539299\",\"4.6292585170340903\",\"4.6392785571142507\",\"4.6492985971944112\",\"4.6593186372745716\",\"4.6693386773547321\",\"4.6793587174348925\",\"4.689378757515053\",\"4.6993987975952134\",\"4.7094188376753738\",\"4.7194388777555343\",\"4.7294589178356947\",\"4.7394789579158552\",\"4.7494989979960156\",\"4.759519038076176\",\"4.7695390781563365\",\"4.7795591182364969\",\"4.7895791583166574\",\"4.7995991983968178\",\"4.8096192384769783\",\"4.8196392785571387\",\"4.8296593186372991\",\"4.8396793587174596\",\"4.84969939879762\",\"4.8597194388777805\",\"4.8697394789579409\",\"4.8797595190381013\",\"4.8897795591182618\",\"4.8997995991984222\",\"4.9098196392785827\",\"4.9198396793587431\",\"4.9298597194389036\",\"4.939879759519064\",\"4.9498997995992244\",\"4.9599198396793849\",\"4.9699398797595453\",\"4.9799599198397058\",\"4.9899799599198662\",\"5.0\"]; setTimeout(function() {\n    $('#slider-W1-26').slider({\n        step: 1, min: 0, max: 499, value: 0,\n        change: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-W1-26-lbl').text(values[position]); interact(26, \"_interact_.update(26, \\\"W1\\\", 2, _interact_.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());_interact_.recompute(26)\"); },\n        slide: function(e,ui) { if(values!=null) $('#slider-W1-26-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-W1-26-lbl').text(values[$('#slider-W1-26').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">W2&nbsp;</font></td><td><table><tr><td>\n        <div id='slider-W2-26' style='margin:0px; margin-left: 1.0em; margin-right: 1.0em; width: 15.0em;'></div>\n        </td><td><font color='black' id='slider-W2-26-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.0\",\"0.01002004008016032\",\"0.02004008016032064\",\"0.030060120240480961\",\"0.040080160320641281\",\"0.050100200400801598\",\"0.060120240480961915\",\"0.070140280561122231\",\"0.080160320641282548\",\"0.090180360721442865\",\"0.10020040080160318\",\"0.1102204408817635\",\"0.12024048096192382\",\"0.13026052104208413\",\"0.14028056112224446\",\"0.15030060120240479\",\"0.16032064128256512\",\"0.17034068136272545\",\"0.18036072144288579\",\"0.19038076152304612\",\"0.20040080160320645\",\"0.21042084168336678\",\"0.22044088176352711\",\"0.23046092184368744\",\"0.24048096192384777\",\"0.2505010020040081\",\"0.26052104208416843\",\"0.27054108216432876\",\"0.28056112224448909\",\"0.29058116232464942\",\"0.30060120240480975\",\"0.31062124248497008\",\"0.32064128256513041\",\"0.33066132264529075\",\"0.34068136272545108\",\"0.35070140280561141\",\"0.36072144288577174\",\"0.37074148296593207\",\"0.3807615230460924\",\"0.39078156312625273\",\"0.40080160320641306\",\"0.41082164328657339\",\"0.42084168336673372\",\"0.43086172344689405\",\"0.44088176352705438\",\"0.45090180360721471\",\"0.46092184368737504\",\"0.47094188376753537\",\"0.4809619238476957\",\"0.49098196392785604\",\"0.50100200400801631\",\"0.51102204408817664\",\"0.52104208416833697\",\"0.5310621242484973\",\"0.54108216432865763\",\"0.55110220440881796\",\"0.56112224448897829\",\"0.57114228456913863\",\"0.58116232464929896\",\"0.59118236472945929\",\"0.60120240480961962\",\"0.61122244488977995\",\"0.62124248496994028\",\"0.63126252505010061\",\"0.64128256513026094\",\"0.65130260521042127\",\"0.6613226452905816\",\"0.67134268537074193\",\"0.68136272545090226\",\"0.69138276553106259\",\"0.70140280561122292\",\"0.71142284569138325\",\"0.72144288577154358\",\"0.73146292585170392\",\"0.74148296593186425\",\"0.75150300601202458\",\"0.76152304609218491\",\"0.77154308617234524\",\"0.78156312625250557\",\"0.7915831663326659\",\"0.80160320641282623\",\"0.81162324649298656\",\"0.82164328657314689\",\"0.83166332665330722\",\"0.84168336673346755\",\"0.85170340681362788\",\"0.86172344689378821\",\"0.87174348697394854\",\"0.88176352705410888\",\"0.89178356713426921\",\"0.90180360721442954\",\"0.91182364729458987\",\"0.9218436873747502\",\"0.93186372745491053\",\"0.94188376753507086\",\"0.95190380761523119\",\"0.96192384769539152\",\"0.97194388777555185\",\"0.98196392785571218\",\"0.99198396793587251\",\"1.0020040080160328\",\"1.0120240480961931\",\"1.0220440881763533\",\"1.0320641282565135\",\"1.0420841683366737\",\"1.0521042084168339\",\"1.0621242484969942\",\"1.0721442885771544\",\"1.0821643286573146\",\"1.0921843687374748\",\"1.102204408817635\",\"1.1122244488977953\",\"1.1222444889779555\",\"1.1322645290581157\",\"1.1422845691382759\",\"1.1523046092184361\",\"1.1623246492985964\",\"1.1723446893787566\",\"1.1823647294589168\",\"1.192384769539077\",\"1.2024048096192372\",\"1.2124248496993975\",\"1.2224448897795577\",\"1.2324649298597179\",\"1.2424849699398781\",\"1.2525050100200383\",\"1.2625250501001986\",\"1.2725450901803588\",\"1.282565130260519\",\"1.2925851703406792\",\"1.3026052104208394\",\"1.3126252505009997\",\"1.3226452905811599\",\"1.3326653306613201\",\"1.3426853707414803\",\"1.3527054108216405\",\"1.3627254509018008\",\"1.372745490981961\",\"1.3827655310621212\",\"1.3927855711422814\",\"1.4028056112224416\",\"1.4128256513026018\",\"1.4228456913827621\",\"1.4328657314629223\",\"1.4428857715430825\",\"1.4529058116232427\",\"1.4629258517034029\",\"1.4729458917835632\",\"1.4829659318637234\",\"1.4929859719438836\",\"1.5030060120240438\",\"1.513026052104204\",\"1.5230460921843643\",\"1.5330661322645245\",\"1.5430861723446847\",\"1.5531062124248449\",\"1.5631262525050051\",\"1.5731462925851654\",\"1.5831663326653256\",\"1.5931863727454858\",\"1.603206412825646\",\"1.6132264529058062\",\"1.6232464929859665\",\"1.6332665330661267\",\"1.6432865731462869\",\"1.6533066132264471\",\"1.6633266533066073\",\"1.6733466933867676\",\"1.6833667334669278\",\"1.693386773547088\",\"1.7034068136272482\",\"1.7134268537074084\",\"1.7234468937875687\",\"1.7334669338677289\",\"1.7434869739478891\",\"1.7535070140280493\",\"1.7635270541082095\",\"1.7735470941883698\",\"1.78356713426853\",\"1.7935871743486902\",\"1.8036072144288504\",\"1.8136272545090106\",\"1.8236472945891709\",\"1.8336673346693311\",\"1.8436873747494913\",\"1.8537074148296515\",\"1.8637274549098117\",\"1.873747494989972\",\"1.8837675350701322\",\"1.8937875751502924\",\"1.9038076152304526\",\"1.9138276553106128\",\"1.923847695390773\",\"1.9338677354709333\",\"1.9438877755510935\",\"1.9539078156312537\",\"1.9639278557114139\",\"1.9739478957915741\",\"1.9839679358717344\",\"1.9939879759518946\",\"2.004008016032055\",\"2.0140280561122155\",\"2.0240480961923759\",\"2.0340681362725364\",\"2.0440881763526968\",\"2.0541082164328572\",\"2.0641282565130177\",\"2.0741482965931781\",\"2.0841683366733386\",\"2.094188376753499\",\"2.1042084168336594\",\"2.1142284569138199\",\"2.1242484969939803\",\"2.1342685370741408\",\"2.1442885771543012\",\"2.1543086172344617\",\"2.1643286573146221\",\"2.1743486973947825\",\"2.184368737474943\",\"2.1943887775551034\",\"2.2044088176352639\",\"2.2144288577154243\",\"2.2244488977955847\",\"2.2344689378757452\",\"2.2444889779559056\",\"2.2545090180360661\",\"2.2645290581162265\",\"2.274549098196387\",\"2.2845691382765474\",\"2.2945891783567078\",\"2.3046092184368683\",\"2.3146292585170287\",\"2.3246492985971892\",\"2.3346693386773496\",\"2.34468937875751\",\"2.3547094188376705\",\"2.3647294589178309\",\"2.3747494989979914\",\"2.3847695390781518\",\"2.3947895791583123\",\"2.4048096192384727\",\"2.4148296593186331\",\"2.4248496993987936\",\"2.434869739478954\",\"2.4448897795591145\",\"2.4549098196392749\",\"2.4649298597194353\",\"2.4749498997995958\",\"2.4849699398797562\",\"2.4949899799599167\",\"2.5050100200400771\",\"2.5150300601202376\",\"2.525050100200398\",\"2.5350701402805584\",\"2.5450901803607189\",\"2.5551102204408793\",\"2.5651302605210398\",\"2.5751503006012002\",\"2.5851703406813606\",\"2.5951903807615211\",\"2.6052104208416815\",\"2.615230460921842\",\"2.6252505010020024\",\"2.6352705410821629\",\"2.6452905811623233\",\"2.6553106212424837\",\"2.6653306613226442\",\"2.6753507014028046\",\"2.6853707414829651\",\"2.6953907815631255\",\"2.7054108216432859\",\"2.7154308617234464\",\"2.7254509018036068\",\"2.7354709418837673\",\"2.7454909819639277\",\"2.7555110220440882\",\"2.7655310621242486\",\"2.775551102204409\",\"2.7855711422845695\",\"2.7955911823647299\",\"2.8056112224448904\",\"2.8156312625250508\",\"2.8256513026052112\",\"2.8356713426853717\",\"2.8456913827655321\",\"2.8557114228456926\",\"2.865731462925853\",\"2.8757515030060135\",\"2.8857715430861739\",\"2.8957915831663343\",\"2.9058116232464948\",\"2.9158316633266552\",\"2.9258517034068157\",\"2.9358717434869761\",\"2.9458917835671365\",\"2.955911823647297\",\"2.9659318637274574\",\"2.9759519038076179\",\"2.9859719438877783\",\"2.9959919839679388\",\"3.0060120240480992\",\"3.0160320641282596\",\"3.0260521042084201\",\"3.0360721442885805\",\"3.046092184368741\",\"3.0561122244489014\",\"3.0661322645290618\",\"3.0761523046092223\",\"3.0861723446893827\",\"3.0961923847695432\",\"3.1062124248497036\",\"3.1162324649298641\",\"3.1262525050100245\",\"3.1362725450901849\",\"3.1462925851703454\",\"3.1563126252505058\",\"3.1663326653306663\",\"3.1763527054108267\",\"3.1863727454909871\",\"3.1963927855711476\",\"3.206412825651308\",\"3.2164328657314685\",\"3.2264529058116289\",\"3.2364729458917894\",\"3.2464929859719498\",\"3.2565130260521102\",\"3.2665330661322707\",\"3.2765531062124311\",\"3.2865731462925916\",\"3.296593186372752\",\"3.3066132264529124\",\"3.3166332665330729\",\"3.3266533066132333\",\"3.3366733466933938\",\"3.3466933867735542\",\"3.3567134268537147\",\"3.3667334669338751\",\"3.3767535070140355\",\"3.386773547094196\",\"3.3967935871743564\",\"3.4068136272545169\",\"3.4168336673346773\",\"3.4268537074148377\",\"3.4368737474949982\",\"3.4468937875751586\",\"3.4569138276553191\",\"3.4669338677354795\",\"3.47695390781564\",\"3.4869739478958004\",\"3.4969939879759608\",\"3.5070140280561213\",\"3.5170340681362817\",\"3.5270541082164422\",\"3.5370741482966026\",\"3.547094188376763\",\"3.5571142284569235\",\"3.5671342685370839\",\"3.5771543086172444\",\"3.5871743486974048\",\"3.5971943887775653\",\"3.6072144288577257\",\"3.6172344689378861\",\"3.6272545090180466\",\"3.637274549098207\",\"3.6472945891783675\",\"3.6573146292585279\",\"3.6673346693386883\",\"3.6773547094188488\",\"3.6873747494990092\",\"3.6973947895791697\",\"3.7074148296593301\",\"3.7174348697394906\",\"3.727454909819651\",\"3.7374749498998114\",\"3.7474949899799719\",\"3.7575150300601323\",\"3.7675350701402928\",\"3.7775551102204532\",\"3.7875751503006136\",\"3.7975951903807741\",\"3.8076152304609345\",\"3.817635270541095\",\"3.8276553106212554\",\"3.8376753507014159\",\"3.8476953907815763\",\"3.8577154308617367\",\"3.8677354709418972\",\"3.8777555110220576\",\"3.8877755511022181\",\"3.8977955911823785\",\"3.9078156312625389\",\"3.9178356713426994\",\"3.9278557114228598\",\"3.9378757515030203\",\"3.9478957915831807\",\"3.9579158316633412\",\"3.9679358717435016\",\"3.977955911823662\",\"3.9879759519038225\",\"3.9979959919839829\",\"4.0080160320641429\",\"4.0180360721443034\",\"4.0280561122244638\",\"4.0380761523046242\",\"4.0480961923847847\",\"4.0581162324649451\",\"4.0681362725451056\",\"4.078156312625266\",\"4.0881763527054265\",\"4.0981963927855869\",\"4.1082164328657473\",\"4.1182364729459078\",\"4.1282565130260682\",\"4.1382765531062287\",\"4.1482965931863891\",\"4.1583166332665495\",\"4.16833667334671\",\"4.1783567134268704\",\"4.1883767535070309\",\"4.1983967935871913\",\"4.2084168336673518\",\"4.2184368737475122\",\"4.2284569138276726\",\"4.2384769539078331\",\"4.2484969939879935\",\"4.258517034068154\",\"4.2685370741483144\",\"4.2785571142284748\",\"4.2885771543086353\",\"4.2985971943887957\",\"4.3086172344689562\",\"4.3186372745491166\",\"4.3286573146292771\",\"4.3386773547094375\",\"4.3486973947895979\",\"4.3587174348697584\",\"4.3687374749499188\",\"4.3787575150300793\",\"4.3887775551102397\",\"4.3987975951904001\",\"4.4088176352705606\",\"4.418837675350721\",\"4.4288577154308815\",\"4.4388777555110419\",\"4.4488977955912024\",\"4.4589178356713628\",\"4.4689378757515232\",\"4.4789579158316837\",\"4.4889779559118441\",\"4.4989979959920046\",\"4.509018036072165\",\"4.5190380761523254\",\"4.5290581162324859\",\"4.5390781563126463\",\"4.5490981963928068\",\"4.5591182364729672\",\"4.5691382765531277\",\"4.5791583166332881\",\"4.5891783567134485\",\"4.599198396793609\",\"4.6092184368737694\",\"4.6192384769539299\",\"4.6292585170340903\",\"4.6392785571142507\",\"4.6492985971944112\",\"4.6593186372745716\",\"4.6693386773547321\",\"4.6793587174348925\",\"4.689378757515053\",\"4.6993987975952134\",\"4.7094188376753738\",\"4.7194388777555343\",\"4.7294589178356947\",\"4.7394789579158552\",\"4.7494989979960156\",\"4.759519038076176\",\"4.7695390781563365\",\"4.7795591182364969\",\"4.7895791583166574\",\"4.7995991983968178\",\"4.8096192384769783\",\"4.8196392785571387\",\"4.8296593186372991\",\"4.8396793587174596\",\"4.84969939879762\",\"4.8597194388777805\",\"4.8697394789579409\",\"4.8797595190381013\",\"4.8897795591182618\",\"4.8997995991984222\",\"4.9098196392785827\",\"4.9198396793587431\",\"4.9298597194389036\",\"4.939879759519064\",\"4.9498997995992244\",\"4.9599198396793849\",\"4.9699398797595453\",\"4.9799599198397058\",\"4.9899799599198662\",\"5.0\"]; setTimeout(function() {\n    $('#slider-W2-26').slider({\n        step: 1, min: 0, max: 499, value: 0,\n        change: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-W2-26-lbl').text(values[position]); interact(26, \"_interact_.update(26, \\\"W2\\\", 3, _interact_.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());_interact_.recompute(26)\"); },\n        slide: function(e,ui) { if(values!=null) $('#slider-W2-26-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-W2-26-lbl').text(values[$('#slider-W2-26').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-26'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
